@@ -14,16 +14,15 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from neutron.callbacks import events
-from neutron.callbacks import registry
-from neutron.callbacks import resources
 from neutron.db import common_db_mixin as base_db
-from neutron.db import l3_agentschedulers_db as l3_agent_db
 from neutron.db import models_v2
-from neutron.extensions import l3 as l3_exception
-from neutron.plugins.common import constants as p_constants
 from neutron.plugins.common import utils
+from neutron_lib.callbacks import events
+from neutron_lib.callbacks import registry
+from neutron_lib.callbacks import resources
 from neutron_lib import constants as lib_constants
+from neutron_lib.exceptions import l3 as l3_exception
+from neutron_lib.plugins import constants as p_constants
 from neutron_lib.plugins import directory
 from oslo_log import log as logging
 from oslo_utils import excutils
@@ -31,7 +30,7 @@ from oslo_utils import uuidutils
 import sqlalchemy as sa
 from sqlalchemy.orm import exc
 
-from neutron_vpnaas._i18n import _LW
+
 from neutron_vpnaas.db.vpn import vpn_models
 from neutron_vpnaas.db.vpn import vpn_validator
 from neutron_vpnaas.extensions import vpn_endpoint_groups
@@ -184,7 +183,7 @@ class VPNPluginDb(vpnaas.VPNPluginBase,
                 dpd_interval=ipsec_sitecon['dpd_interval'],
                 dpd_timeout=ipsec_sitecon['dpd_timeout'],
                 admin_state_up=ipsec_sitecon['admin_state_up'],
-                status=p_constants.PENDING_CREATE,
+                status=lib_constants.PENDING_CREATE,
                 vpnservice_id=vpnservice_id,
                 ikepolicy_id=ipsec_sitecon['ikepolicy_id'],
                 ipsecpolicy_id=ipsec_sitecon['ipsecpolicy_id'],
@@ -464,6 +463,7 @@ class VPNPluginDb(vpnaas.VPNPluginBase,
                'tenant_id': vpnservice['tenant_id'],
                'subnet_id': vpnservice['subnet_id'],
                'router_id': vpnservice['router_id'],
+               'flavor_id': vpnservice['flavor_id'],
                'admin_state_up': vpnservice['admin_state_up'],
                'external_v4_ip': vpnservice['external_v4_ip'],
                'external_v6_ip': vpnservice['external_v6_ip'],
@@ -472,6 +472,7 @@ class VPNPluginDb(vpnaas.VPNPluginBase,
 
     def create_vpnservice(self, context, vpnservice):
         vpns = vpnservice['vpnservice']
+        flavor_id = vpns.get('flavor_id', None)
         validator = self._get_validator()
         with context.session.begin(subtransactions=True):
             validator.validate_vpnservice(context, vpns)
@@ -482,8 +483,9 @@ class VPNPluginDb(vpnaas.VPNPluginBase,
                 description=vpns['description'],
                 subnet_id=vpns['subnet_id'],
                 router_id=vpns['router_id'],
+                flavor_id=flavor_id,
                 admin_state_up=vpns['admin_state_up'],
-                status=p_constants.PENDING_CREATE)
+                status=lib_constants.PENDING_CREATE)
             context.session.add(vpnservice_db)
         return self._make_vpnservice_dict(vpnservice_db)
 
@@ -543,10 +545,11 @@ class VPNPluginDb(vpnaas.VPNPluginBase,
                        "(%(services)s)" % {'plural': plural,
                                            'services': services})
 
-    def check_subnet_in_use(self, context, subnet_id):
+    def check_subnet_in_use(self, context, subnet_id, router_id):
         with context.session.begin(subtransactions=True):
             vpnservices = context.session.query(
-                vpn_models.VPNService).filter_by(subnet_id=subnet_id).first()
+                vpn_models.VPNService).filter_by(
+                    subnet_id=subnet_id, router_id=router_id).first()
             if vpnservices:
                 raise vpnaas.SubnetInUseByVPNService(
                     subnet_id=subnet_id,
@@ -637,28 +640,6 @@ class VPNPluginDb(vpnaas.VPNPluginBase,
 
 
 class VPNPluginRpcDbMixin(object):
-    def _get_agent_hosting_vpn_services(self, context, host):
-
-        plugin = directory.get_plugin()
-        agent = plugin._get_agent_by_type_and_host(
-            context, lib_constants.AGENT_TYPE_L3, host)
-        agent_conf = plugin.get_configuration_dict(agent)
-        # Retrieve the agent_mode to check if this is the
-        # right agent to deploy the vpn service. In the
-        # case of distributed the vpn service should reside
-        # only on a dvr_snat node.
-        agent_mode = agent_conf.get('agent_mode', 'legacy')
-        if not agent.admin_state_up or agent_mode == 'dvr':
-            return []
-        query = context.session.query(vpn_models.VPNService)
-        query = query.join(vpn_models.IPsecSiteConnection)
-        query = query.join(l3_agent_db.RouterL3AgentBinding,
-                           l3_agent_db.RouterL3AgentBinding.router_id ==
-                           vpn_models.VPNService.router_id)
-        query = query.filter(
-            l3_agent_db.RouterL3AgentBinding.l3_agent_id == agent.id)
-        return query
-
     def _build_local_subnet_cidr_map(self, context):
         """Build a dict of all local endpoint subnets, with list of CIDRs."""
         query = context.session.query(models_v2.Subnet.id,
@@ -698,7 +679,7 @@ class VPNPluginRpcDbMixin(object):
                     vpnservice_db = self._get_vpnservice(
                         context, vpnservice['id'])
                 except vpnaas.VPNServiceNotFound:
-                    LOG.warning(_LW('vpnservice %s in db is already deleted'),
+                    LOG.warning('vpnservice %s in db is already deleted',
                                 vpnservice['id'])
                     continue
 
@@ -716,13 +697,12 @@ def vpn_callback(resource, event, trigger, **kwargs):
     vpn_plugin = directory.get_plugin(p_constants.VPN)
     if vpn_plugin:
         context = kwargs.get('context')
+        router_id = kwargs.get('router_id')
         if resource == resources.ROUTER_GATEWAY:
-            check_func = vpn_plugin.check_router_in_use
-            resource_id = kwargs.get('router_id')
+            vpn_plugin.check_router_in_use(context, router_id)
         elif resource == resources.ROUTER_INTERFACE:
-            check_func = vpn_plugin.check_subnet_in_use
-            resource_id = kwargs.get('subnet_id')
-        check_func(context, resource_id)
+            subnet_id = kwargs.get('subnet_id')
+            vpn_plugin.check_subnet_in_use(context, subnet_id, router_id)
 
 
 def migration_callback(resource, event, trigger, **kwargs):
