@@ -11,11 +11,11 @@ VENV=${1:-"dsvm-functional"}
 function generate_testr_results {
     # Give job user rights to access tox logs
     sudo -H -u $owner chmod o+rw .
-    sudo -H -u $owner chmod o+rw -R .testrepository
-    if [ -f ".testrepository/0" ] ; then
-        .tox/$VENV/bin/subunit-1to2 < .testrepository/0 > ./testrepository.subunit
-        $SCRIPTS_DIR/subunit2html ./testrepository.subunit testr_results.html
-        gzip -9 ./testrepository.subunit
+    sudo -H -u $owner chmod o+rw -R .stestr
+    if [ -f ".stestr/0" ] ; then
+        .tox/$VENV/bin/subunit-1to2 < .stestr/0 > ./stestr.subunit
+        $SCRIPTS_DIR/subunit2html ./stestr.subunit testr_results.html
+        gzip -9 ./stestr.subunit
         gzip -9 ./testr_results.html
         sudo mv ./*.gz /opt/stack/logs/
     fi
