@@ -14,7 +14,6 @@
 #    under the License.
 
 import mock
-from neutron.agent.l3 import legacy_router
 from neutron_lib.callbacks import registry
 from oslo_config import cfg
 from oslo_utils import uuidutils
@@ -90,43 +89,3 @@ class TestVirtualPrivateNetworkDeviceDriverLoading(VPNBaseTestCase):
                               'vpnagent')
         self.assertRaises(vpnaas.DeviceDriverImportError,
                           self.service.load_device_drivers, 'host')
-
-
-class TestVPNServiceEventHandlers(VPNBaseTestCase):
-
-    def setUp(self):
-        super(TestVPNServiceEventHandlers, self).setUp()
-        self.l3_agent = mock.Mock()
-        self.l3_agent.context = mock.sentinel.context
-        mock.patch.object(registry, 'subscribe').start()
-        self.service = vpn_service.VPNService(mock.Mock())
-        self.device_driver = mock.Mock()
-        self.l3_agent.device_drivers = [self.device_driver]
-
-    def test_router_added_actions(self):
-        ri = legacy_router.LegacyRouter(router_id=FAKE_ROUTER_ID,
-                                        agent=self.l3_agent,
-                                        **self.ri_kwargs)
-        vpn_service.router_added_actions(mock.Mock(), mock.Mock(),
-                                         self.l3_agent, router=ri)
-        self.device_driver.create_router.assert_called_once_with(ri)
-        self.device_driver.sync.assert_called_once_with(self.l3_agent.context,
-                                                        [ri.router])
-
-    def test_router_removed_actions(self):
-        ri = legacy_router.LegacyRouter(router_id=FAKE_ROUTER_ID,
-                                        agent=self.l3_agent,
-                                        **self.ri_kwargs)
-        vpn_service.router_removed_actions(mock.Mock(), mock.Mock(),
-                                           self.l3_agent, router=ri)
-        self.device_driver.destroy_router.assert_called_once_with(
-            FAKE_ROUTER_ID)
-
-    def test_router_updated_actions(self):
-        ri = legacy_router.LegacyRouter(router_id=FAKE_ROUTER_ID,
-                                        agent=self.l3_agent,
-                                        **self.ri_kwargs)
-        vpn_service.router_updated_actions(mock.Mock(), mock.Mock(),
-                                           self.l3_agent, router=ri)
-        self.device_driver.sync.assert_called_once_with(self.l3_agent.context,
-                                                        [ri.router])
